@@ -10,7 +10,8 @@ from selenium.webdriver.support.ui import WebDriverWait
 from selenium.webdriver.common.by import By
 from selenium.webdriver.common.proxy import Proxy, ProxyType
 from selenium.common.exceptions import WebDriverException
-from selenium.common.exceptions import TimeoutException
+from selenium.webdriver import ActionChains, Keys
+from selenium.webdriver.support import expected_conditions as EC
 
 
 def create_proxy() -> Proxy:
@@ -72,11 +73,12 @@ class BaseElement:
         find_element = driver.find_elements if multiple else driver.find_element
         try:
             WebDriverWait(driver, wait_time).until(
-                lambda driver: find_element(*locator)
+                lambda driver: EC.element_to_be_clickable(locator)
             )
             self.element = find_element(*locator)
-        except TimeoutException:
+        except:
             if optional:
+                self.element = None
                 return
 
             print(f"Timed out trying to get element ({locate_by} = {locate_value})")
@@ -88,24 +90,35 @@ class BaseElement:
 class Text(BaseElement):
     @property
     def text(self) -> str:
+        if self.element is None:
+            return ""
+
         return self.element.get_attribute("text")
 
 
 class TextArea(BaseElement):
     def write(self, value: str) -> None:
-        try:
-            self.element.clear()
-        except:
-            pass
-        self.element.send_keys(*value)
+        if self.element is None:
+            return
+
+        actions_handler = ActionChains(self.driver).move_to_element(self.element)
+        actions_handler.click().key_down(Keys.CONTROL).send_keys("a").perform()
+        actions_handler.send_keys(Keys.CLEAR).key_up(Keys.CONTROL).perform()
+        actions_handler.send_keys(*value).perform()
 
     @property
     def value(self) -> None:
+        if self.element is None:
+            return ""
+
         return self.element.get_attribute("value")
 
 
 class Button(BaseElement):
     def click(self) -> None:
+        if self.element is None:
+            return
+
         try:
             can_click = getattr(self.element, "click", None)
             if callable(can_click):
